# Changelog

## 0.2.0

This is the first release which uses the `CHANGELOG` file.

- Widen support from just Python 3.11 to Python 3.9, 3.10, 3.11, and 3.12 ([#3](https://github.com/sebpretzer/rst-in-md/pull/3))
- Add support for SuperFences ([#4](https://github.com/sebpretzer/rst-in-md/pull/4))
- Auto-Configure SuperFence custom fences ([#5](https://github.com/sebpretzer/rst-in-md/pull/5))

## 0.1.0

- Initial release
- Support for Python 3.11
